from custompacks import ExcelParser
class Translated:
    def __init__(self):
        self.dataframe = ExcelParser(r"V:\Findep\Incoming\test\DevOps\References\Translation.xlsx",
                                     "Sheet1",
                                     "Company_code").read_data()
        self.dataframe.loc[:, 'Company_code'] = self.dataframe.loc[:, 'Company_code'].astype(str).str.split(
            ".").str.get(0)


if __name__ == '__main__':
    parse_data = Translated()
    print(parse_data.dataframe)






from custompacks import ExcelParser_retain_duplicates, DataframeCleaner, MasterData

class GetOSV:

    def __init__(self, filepath, sht_name, index):
        self.filepath = filepath
        self.sht_name = sht_name
        self.index = index
        self.df = ExcelParser_retain_duplicates(self.filepath, self.sht_name, self.index).read_data()

    def further_process(self):
        self.df = self.df.iloc[:, slice(2, 13)]
        self.df.columns = ['Corp Acc', 'Text Rus', 'Text Eng',
                           'Initials_Dr', 'Initials_Cr', 'OB_adj_Dr', 'OB_adj_Cr', 'Accruals_Dr', 'Accruals_Cr',
                           'CB_Dr', 'CB_Cr']
        self.df['Corp Acc'] = self.df['Corp Acc'].astype(str).str.split(".").str.get(0)
        MasterData_dict = MasterData().further_process().set_index('Corp Acc').T.to_dict()
        self.df['Consolidation_Account'] = self.df['Corp Acc'].apply(lambda x:
                     MasterData_dict.get(x).get('Consolidation Account') if MasterData_dict.get(x) else None)
        self.df['Consolidation_Account'] = self.df['Consolidation_Account'].astype(str).str.split(".").str.get(0)


        return self.df


if __name__ == '__main__':
    x = GetOSV(r'V:\Accounting\Work\Мерц\2023\3 квартал\Июль 2023\Отчетность\Detail_July_2023.xlsx',
               'ОСВ_Июль_2023',
               'Rus Account')

    x.further_process().to_clipboard()


import pandas as pd

pd.options.display.width = None


class DataframeCleaner:
    def __init__(self, frame: pd.DataFrame):
        self.df = frame.copy()
        self._strip_values()
        self._remove_nans()

    def _strip_values(self):
        self.df = self.df.applymap(lambda x: x.strip() if isinstance(x, str) else x)

    def _remove_nans(self):
        self.df = self.df.dropna(how='all', axis=1)
        self.df = self.df.dropna(how='all', axis=0).reset_index(drop=True)
        # self.df = self.df[~self.df.isin(['']).all(axis = 1)]

    def adj_by_row_index(self, value: str):
        row_idx = self.df.index[self.df.eq(value).any(axis=1)]
        self.df.columns = self.df.loc[row_idx[0]].values
        self.df = self.df.drop(index = range(row_idx[0]+1))

        return self.df

    def remove_duplicated_cols(self):
        self.df = self.df.loc[:, ~self.df.columns.duplicated()]
        return self.df

    def __repr__(self):
        return self.df.__repr__()


if __name__ == '__main__':
    # Example usage:
    df = pd.read_excel(r'C:\Users\slalnazarov\Documents\04082023.xlsx')
    cleaner = DataframeCleaner(df)
    cleaner.adj_by_row_index("Name")
    cleaner.remove_duplicated_cols()
    cleaner.df.to_clipboard()




import re

from custompacks import ExcelParser, MasterData, GetVendors, GetCustomers, Translated
import numpy as np
import pandas as pd


class ParseAccruals:
    def __init__(self, filepath, sht, index, report_date) -> None:
        self.filepath = filepath
        self.sht = sht
        self.index = index
        self.report_date = report_date
        self.dataframe = ExcelParser(self.filepath,
                                     self.sht,
                                     self.index).read_data()
        self.dataframe["Дт"] = self.dates_to_strings(self.dataframe["Дт"].astype(str))
        self.dataframe["Кт"] = self.dates_to_strings(self.dataframe["Кт"].astype(str))
        self.dataframe["МВЗ"] = (
            self.dataframe["МВЗ"].astype(str).str.split(".").str.get(0)
        )
        self.dataframe = self.dataframe.astype(str).reset_index(drop=True)
        self.CoA = MasterData().further_process()
        self.CoA = self.CoA.drop_duplicates(subset='Rus Account', keep='first')

        self.mydict = self.CoA.set_index('Rus Account').T.to_dict()
        self.mydict2 = self.CoA.set_index('Corp Acc').T.to_dict()
        self.vendors = GetVendors(filepath=r'V:\Findep\Incoming\test\DevOps\References\LFA1 22082023.txt',
                                  value='LIFNR').further_process().set_index("LIFNR").T.to_dict()
        self.customers = GetCustomers(filepath=r'V:\Findep\Incoming\test\DevOps\References\KNA1 22082023.txt',
                                      value='KUNNR').further_process().set_index("KUNNR").T.to_dict()
        self.translated = Translated().dataframe.set_index("Company_code").T.to_dict()

    def define_corp_acc(self, x):
        if self.mydict.get(x):
            return self.mydict.get(x).get("Corp Acc")
        else:
            return "not applicable"

    def get_name(self, code):
        # pass
        if self.vendors.get(code) is not None:
            return self.vendors.get(code, {}).get("NAME1")
        else:
            return self.customers.get(code, {}).get("NAME1")

    @staticmethod
    @np.vectorize
    def offset_date(x, y):
        return x + pd.offsets.Day(y)

    @staticmethod
    @np.vectorize
    def lines_to_duplicate(x, y):
        if x != "not applicable" and y != "not applicable":
            return "we have to duplicate this line"
        if x == "not applicable" and y != "not applicable":
            return y
        if x != "not applicable" and y == "not applicable":
            return x

    def get_days(self, row):
        x = row['Company_code']
        y = row['Rap Account']
        z = row['Описание операции']
        a = self.customers.get(x)
        if a:
            if a.get('channel') == 'AS_Retail' and y == '62.01.05' and not str(z).__contains__('опт'):
                return a.get("Отсрочка платежа, дни, розница")
            elif a.get('channel') == 'AS_WholeSales' and y == '62.01.05' and not str(z).__contains__('опт'):
                return a.get("Отсрочка платежа, дни, розница")
            elif a.get('channel') == 'AS_WholeSales' and y == '62.01.05' and str(z).__contains__('опт'):
                return a.get("Отсрочка платежа, дни, опт")
            elif a.get('channel') == 'Mobility channel':
                return a.get("Отсрочка платежа (дн.)")
            elif a.get('channel') == 'not applicable':
                return 0
        else:
            return 0

        # pass

    @staticmethod
    @np.vectorize
    def get_counterparty(x: pd.Series, y: pd.Series) -> pd.Series:
        if x in [None, "None", ""]:
            return y
        elif y in [None, "None", ""]:
            return x
        elif y not in [None, "None", ""] and x not in [None, "None", ""]:
            return x

    def further_process(self):
        self.dataframe["Corp Account_Dr"] = self.dataframe.apply(lambda row: self.define_corp_acc(row["Дт"]), axis=1)
        self.dataframe["Corp Account_Cr"] = self.dataframe.apply(lambda row: self.define_corp_acc(row["Кт"]), axis=1)

        self.dataframe['category_Dr'] = self.dataframe['Corp Account_Dr'].apply(
            lambda x: self.mydict2.get(x).get("reporting_line") if self.mydict2.get(x) else x
        )

        self.dataframe['acc_group_Dr'] = self.dataframe['Corp Account_Dr'].apply(
            lambda x: self.mydict2.get(x).get("accounting group") if self.mydict2.get(x) else x
        )

        self.dataframe['category_Cr'] = self.dataframe['Corp Account_Cr'].apply(
            lambda x: self.mydict2.get(x).get("reporting_line") if self.mydict2.get(x) else x)

        self.dataframe['acc_group_Cr'] = self.dataframe['Corp Account_Cr'].apply(
            lambda x: self.mydict2.get(x).get("accounting group") if self.mydict2.get(x) else x)

        conds = [
            ((self.dataframe['acc_group_Dr'].isin(['', None])) &
             (self.dataframe['Corp Account_Dr'].str.startswith(('1', '2', '3')))),

            ((self.dataframe['acc_group_Dr'].isin(['', None])) &
             (self.dataframe['Corp Account_Dr'].str.startswith(('4', '5', '6', '7'))))

        ]

        conds_2 = [
            ((self.dataframe['acc_group_Cr'].isin(['', None])) &
             (self.dataframe['Corp Account_Cr'].str.startswith(('1', '2', '3')))),

            ((self.dataframe['acc_group_Cr'].isin(['', None])) &
             (self.dataframe['Corp Account_Cr'].str.startswith(('4', '5', '6', '7'))))

        ]

        choices = [
            'bs',
            'pl'
        ]

        self.dataframe['acc_group_Dr'] = np.select(conds, choices, default=self.dataframe['acc_group_Dr'])
        self.dataframe['acc_group_Cr'] = np.select(conds_2, choices, default=self.dataframe['acc_group_Cr'])

        return self.dataframe

    def make_bs_data(self, ag_dr='bs', ag_cr='bs'):
        df = self.further_process().copy()
        df = df[df.apply(lambda row: True if row['acc_group_Dr'] == ag_dr or row['acc_group_Cr'] == ag_cr else False,
                         axis=1)]

        return df

    def make_pnl_data(self, ag_dr='pl', ag_cr='pl'):
        df = self.further_process().copy()
        conds = [
            (df['acc_group_Dr'] == ag_dr) & (df['acc_group_Cr'] == ag_cr),
            (df['acc_group_Dr'] != ag_dr) & (df['acc_group_Cr'] == ag_cr),
            (df['acc_group_Dr'] == ag_dr) & (df['acc_group_Cr'] != ag_cr)
        ]
        choices = [
            True,
            True,
            True
        ]
        df = df[np.select(conds, choices, default=False)]
        df.reset_index(drop=True, inplace=True)

        conds_2 = [

            (df['acc_group_Dr'] == ag_dr) & (df['acc_group_Cr'] == ag_cr),
            (df['acc_group_Dr'] != ag_dr) & (df['acc_group_Cr'] == ag_cr),
            (df['acc_group_Dr'] == ag_dr) & (df['acc_group_Cr'] != ag_cr),

        ]
        choices_2 = [
            'duplicate this line',
            df['Corp Account_Cr'],
            df['Corp Account_Dr']

        ]
        df["Corp Account"] = np.select(conds_2, choices_2, default=None)
        sp_idx = df[(df == "duplicate this line").any(axis=1)].index

        for item in sp_idx:
            s = df.iloc[item, :].values
            s = [str(item) + "_make a dup of_" if item == "duplicate this line"
                 else item for item in s]
            df.loc[len(df)] = s

        condslast = [
            df.loc[:, "Corp Account"].isin(["duplicate this line"]),
            df.loc[:, "Corp Account"].isin(["duplicate this line_make a dup of_"])
        ]

        choiceslast = [
            df.loc[:, "Corp Account_Dr"],
            df.loc[:, "Corp Account_Cr"],
        ]

        df['Corp Account'] = np.select(condslast, choiceslast, default=df['Corp Account'])

        conds = [
            (df['acc_group_Cr'] == 'pl') & (df['acc_group_Dr'] == 'pl') & (df['Corp Account'].str.startswith('4')),
            (df['acc_group_Cr'] == 'pl') & (df['acc_group_Dr'] == 'pl') & (df['Corp Account'].str.startswith('5')),
            df['acc_group_Cr'] == 'pl',

        ]
        choices = [
            df['Сумма'].astype(float),
            df['Сумма'].astype(float) * -1,
            df['Сумма'].astype(float) * -1,
        ]
        df['Сумма'] = np.select(conds, choices, default=df['Сумма'])

        df.drop(columns=['Corp Account_Dr', 'Corp Account_Cr', 'category_Dr', 'acc_group_Dr', 'acc_group_Cr',
                         'category_Cr', 'Код НДС'],
                inplace=True)
        df['FS line'] = df['Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("FS Line Name") if self.mydict2.get(x) else x
        )
        df['Report line'] = df['Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("reporting_line") if self.mydict2.get(x) else x
        )
        df['Период, к которому относятся расходы'] = pd.to_datetime(self.report_date).date()
        df['Corp Account Name'] = df["Corp Account"].apply(
            lambda x: self.mydict2.get(x).get("Local Account Name") if self.mydict2.get(x) else x)

        df['Group Account Code'] = df["Corp Account"].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account") if self.mydict2.get(x) else x)
        df['Group Account Code Name'] = df["Corp Account"].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account Name") if self.mydict2.get(x) else x)

        df['Кредитор/дебитор ДТ'] = df['Кредитор/дебитор ДТ'].astype(str).str.split(".").str.get(0)
        df['Кредитор/дебитор КТ'] = df['Кредитор/дебитор КТ'].astype(str).str.split(".").str.get(0)

        df["CounterParty SAP code"] = self.get_counterparty(
            df["Кредитор/дебитор ДТ"], df["Кредитор/дебитор КТ"]
        )

        conds_3 = [
            df["Описание операции"].str.contains("для HMC", flags=re.I),
            df["CounterParty SAP code"].isin([None, "None", "без кредитора"]),
        ]

        choices_3 = ["SBC3", "not applicable"]

        df["CounterParty SAP code"] = np.select(
            conds_3, choices_3, default=df["CounterParty SAP code"]
        )
        df["CounterParty SAP name"] = df["CounterParty SAP code"].apply(
            lambda x: self.get_name(x)
        )

        return df

    def make_accruals_for_ARAP(self, ag_dr='bs', ag_cr='bs'):
        df = self.make_bs_data().copy()
        conds_1 = [
            df['category_Dr'].isin(['AR', 'Other AR', 'AP', 'Other AP']),
            df['category_Cr'].isin(['AR', 'Other AR', 'AP', 'Other AP'])
        ]
        choices_1 = [
            df['Corp Account_Dr'],
            df['Corp Account_Cr']
        ]

        df['Corp Account'] = np.select(conds_1, choices_1, default=None)
        df = df[pd.notna(df['Corp Account'])]

        conds_2 = [
            df['category_Cr'].isin(['AP', 'Other AP']),
            df['category_Dr'].isin(['AR', 'Other AR']),
            df['category_Dr'].isin(['AP', 'Other AP']),
            df['category_Cr'].isin(['AR', 'Other AR'])
        ]
        choices_2 = [
            df['Сумма'].astype(float) * -1,
            df['Сумма'].astype(float) * 1,
            df['Сумма'].astype(float) * 1,
            df['Сумма'].astype(float) * -1,

        ]
        df['Сумма'] = np.select(conds_2, choices_2, default=df['Сумма'])

        conds_3 = [

            (df['category_Dr'].isin(['AR', 'Other AR', 'AP', 'Other AP'])) &
            (df['category_Cr'].isin(['AR', 'Other AR', 'AP', 'Other AP']))

        ]
        choices_3 = [
            'duplicate this line',

        ]

        df["Corp Account"] = np.select(conds_3, choices_3, default=df["Corp Account"])
        df.reset_index(drop=True, inplace=True)

        sp_idx = df[(df == "duplicate this line").any(axis=1)].index

        for item in sp_idx:
            s = df.iloc[item, :].values
            s = [str(item) + "_make a dup of_" if item == "duplicate this line"
                 else item for item in s]
            df.loc[len(df)] = s

        condslast = [
            df.loc[:, "Corp Account"].isin(["duplicate this line"]),
            df.loc[:, "Corp Account"].isin(["duplicate this line_make a dup of_"])
        ]

        choiceslast = [
            df.loc[:, "Corp Account_Dr"],
            df.loc[:, "Corp Account_Cr"],
        ]

        df['Corp Account'] = np.select(condslast, choiceslast, default=df['Corp Account'])

        conds_4 = [
            (df['category_Dr'].isin(['AR', 'Other AR', 'AP', 'Other AP'])) &
            (df['category_Cr'].isin(['AR', 'Other AR', 'AP', 'Other AP'])) &
            (df['Corp Account'].str.startswith(('2', '3'))),

            (df['category_Dr'].isin(['AR', 'Other AR', 'AP', 'Other AP'])) &
            (df['category_Cr'].isin(['AR', 'Other AR', 'AP', 'Other AP'])) &
            (df['Corp Account'].str.startswith('1'))
        ]
        choices_4 = [
            df['Сумма'],
            df['Сумма'] * -1
        ]
        df['Сумма'] = np.select(conds_4, choices_4, default=df['Сумма'])
        cols_to_drop = ['НОМЕР ROA', 'Corp Account_Dr', 'Corp Account_Cr', 'category_Dr',
                        'acc_group_Dr', 'category_Cr', 'acc_group_Cr']
        df.drop(columns=cols_to_drop, inplace=True)
        df.loc[:, "Corp Account Name"] = df["Corp Account"].apply(
            lambda x: self.mydict2.get(x).get("Local Account Name") if self.mydict2.get(x) else x)
        df.loc[:, "Rap Account"] = df["Corp Account"].apply(
            lambda x: self.mydict2.get(x).get("Rus Account") if self.mydict2.get(x) else x)
        df.loc[:, "Group Account Number"] = df.loc[:, "Corp Account"] \
            .apply(lambda x: self.mydict2.get(x).get("Consolidation Account") if self.mydict2.get(x) else x)
        df.loc[:, "Group Account Name"] = df.loc[:, "Corp Account"] \
            .apply(lambda x: self.mydict2.get(x).get("Consolidation Account Name") if self.mydict2.get(x) else x)
        df.loc[:, "Group Account Name_Korean"] = df.loc[:, "Corp Account"].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account Korean Name") if self.mydict2.get(x) else x)

        df["Кредитор/дебитор ДТ"] = (
            df["Кредитор/дебитор ДТ"].astype(str).str.split(".").str.get(0)
        )
        df["Кредитор/дебитор КТ"] = (
            df["Кредитор/дебитор КТ"].astype(str).str.split(".").str.get(0)
        )
        df["Company_code"] = self.get_counterparty(
            df["Кредитор/дебитор ДТ"], df["Кредитор/дебитор КТ"]
        )

        conds_4 = [
            df["Описание операции"].str.contains("для HMC", flags=re.I),
            df["Company_code"].isin([None, "None", "без кредитора"]),
        ]

        choices_4 = ["SBC3", "not applicable"]

        df["Company_code"] = np.select(conds_4, choices_4, default=df["Company_code"])

        df["Company_code"] = (df["Company_code"].astype(str).str.split(".").str.get(0))
        df["Company_name"] = df["Company_code"].apply(lambda x: self.get_name(x))
        df['Период, к которому относятся расходы'] = pd.to_datetime(self.report_date).date()
        cols_to_drop = ['Кредитор/дебитор ДТ', 'Кредитор/дебитор КТ', 'Код НДС', 'Дт', 'Кт']
        df.drop(columns=cols_to_drop, inplace=True)
        df["Deferred_Payment_Days"] = df.apply(lambda row: self.get_days(row), axis=1)
        df["Deferred_Payment_Days"] = df["Deferred_Payment_Days"]. \
            apply(lambda x: int(str(x).split(".")[0]) if pd.notna(x) else 0)
        df["Due Date"] = self.offset_date(
            df["Период, к которому относятся расходы"],
            df["Deferred_Payment_Days"])
        df["Overdue days"] = (pd.to_datetime(self.report_date) - pd.to_datetime(df["Due Date"])).apply(lambda x: x.days)
        df["Transaction Type"] = "Accruals"
        bins = [-1000, 0, 31, 61, 90, 20000]
        group_names = ["Before due date", "0-30", "31-60", "61-90", "over 90 days"]

        df["Param"] = pd.cut(df["Overdue days"], bins=bins, labels=group_names)
        df.rename(columns={
            "Период, к которому относятся расходы": "Pstng Date",
            "Сумма": "Amount in LC",
            "Ответственный отдел в ОБО": "DocumentNo",
            "Описание операции": "Text",
        },
            inplace=True,
        )

        df['Company_name'] = df.apply(
            lambda row: self.translated.get(row['Company_code'], {}).get("Translated", row['Company_name']),
            axis=1
        )
        df['Category'] = df['Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("reporting_line") if self.mydict2.get(x) else x
        )

        # conds_5 = [ df['category'].isin(['AP', 'Other AP'])  ]
        # choices_5 = [ df['Amount in LC'] * -1 ]
        #
        # df['Amount in LC'] = np.select(conds_5, choices_5, default=df['Amount in LC'])
        # df = df[pd.notna(df['corp account'])]

        return df

    @staticmethod
    @np.vectorize
    def dates_to_strings(col: pd.Series):
        if len(col) == 8:
            return col
        elif col in [None, "None"]:
            return None
        elif len(col) == 5:
            return col
        else:
            return pd.to_datetime(col, dayfirst=False).strftime("%d.%m.%y")


if __name__ == '__main__':
    obj1 = ParseAccruals(
        r"V:\Accounting\Work\Мерц\2023\3 квартал\Июль 2023\Отчетность\!Начисление МСФО_июль 2023.xlsx",
        "для if загрузки",
        "Отдел инициатор",
        "07/31/2023",
    )
    print(obj1.make_accruals_for_ARAP().to_clipboard())



from custompacks import TxtParser, GetVendors, GetCustomers, MasterData, Translated
import numpy as np
import pandas as pd


class Initials:
    def __init__(self, AR_filepath: str = None, AP_filepath: str = None, index: str = 'Account',
                 report_date: str = None):

        self.vendors = GetVendors(filepath=r'V:\Findep\Incoming\test\DevOps\References\LFA1 22082023.txt',
                                  value='LIFNR').further_process().set_index("LIFNR").T.to_dict()
        self.customers = GetCustomers(filepath=r'V:\Findep\Incoming\test\DevOps\References\KNA1 22082023.txt',
                                      value='KUNNR').further_process().set_index("KUNNR").T.to_dict()
        self.CoA = MasterData().further_process()
        self.CoA = self.CoA.drop_duplicates(subset='Rus Account', keep='first')
        self.mydict = self.CoA.set_index('Rus Account').T.to_dict()
        self.mydict2 = self.CoA.set_index('Corp Acc').T.to_dict()
        self.translated = Translated().dataframe.set_index("Company_code").T.to_dict()
        self.AP_path = AP_filepath
        self.AR_path = AR_filepath
        self.index = index
        self.report_date = report_date

        if self.AP_path is not None:
            self.AP_df = TxtParser(self.AP_path, self.index).read_data()
        else:
            self.AR_df = TxtParser(self.AR_path, self.index).read_data()

    def get_days(self, row):
        x = row['Company_code']
        y = row['Rap Account']
        z = row['Text']
        a = self.customers.get(x)
        if a:
            if a.get('channel') == 'AS_Retail' and y == '62.01.05' and not str(z).__contains__('опт'):
                return a.get("Отсрочка платежа, дни, розница")
            elif a.get('channel') == 'AS_WholeSales' and y == '62.01.05' and str(z).__contains__('опт'):
                return a.get("Отсрочка платежа, дни, опт")
            elif a.get('channel') == 'AS_WholeSales' and y == '62.01.05' and not str(z).__contains__('опт'):
                return a.get("Отсрочка платежа, дни, розница")
            elif a.get('channel') == 'Mobility channel':
                return a.get("Отсрочка платежа (дн.)")
            elif a.get('channel') == 'not applicable':
                return 0
        else:
            return 0

    def get_name(self, code):
        if self.vendors.get(code):
            return self.vendors.get(code).get("NAME1")
        elif self.customers.get(code):
            return self.customers.get(code).get("NAME1")
        else:
            return 'not applicable'

    @staticmethod
    @np.vectorize
    def offset_date(x, y):
        return x + pd.offsets.Day(y)

    @staticmethod
    @np.vectorize
    def format_string(x):
        if type(x) == str and x.startswith('00'):
            return str(int(x))
        elif type(x) == str and not x.startswith('00'):
            return x
        else:
            return x

    @staticmethod
    @np.vectorize
    def trailing_negative_numbers_(x):
        x = str(x).replace(",", "")
        if x[-1] == '-':
            return np.float64(x[-1] + x[:-1])
        else:
            return np.float64(x)

    def make_ap_df(self):

        self.AP_df = self.AP_df.drop(columns=self.AP_df.columns[self.AP_df.columns.str.contains("Unnamed")
                                                                | self.AP_df.columns.isin(['TTy', 'AccTy', ''])])
        self.AP_df['Rap Account'] = self.AP_df['Account'].apply(lambda x: \
                                                                    self.mydict2.get(x).get(
                                                                        "Rus Account") if self.mydict2.get(
                                                                        x) is not None else None)
        self.AP_df = self.AP_df[~self.AP_df['Rap Account'].isin(['76.02.00', '60.01.00', '', None])]

        self.AP_df = self.AP_df[~self.AP_df['Account'].isin([np.nan, "", None, 'nan', "Account", "None"])]
        self.AP_df['Amount in LC'] = self.trailing_negative_numbers_(self.AP_df['Amount in LC'])
        self.AP_df[['Doc. Date', 'Pstng Date', 'Entry Date']] = self.AP_df[
            ['Doc. Date', 'Pstng Date', 'Entry Date']].applymap(
            lambda x: x.split(".")[2] + "-" + x.split(".")[1] + "-" + x.split(".")[0]).astype('datetime64[ns]')
        self.AP_df['Entry date and time'] = self.AP_df['Entry Date'].astype(str) + " " + self.AP_df['Time']
        self.AP_df['Entry date and time'] = self.AP_df['Entry date and time'].astype('datetime64[ns]')

        self.AP_df['DocumentNo'] = self.AP_df['DocumentNo'].str.split(".").str.get(0)
        self.AP_df['Sp.G/L ass'] = self.format_string(self.AP_df['Sp.G/L ass'])
        self.AP_df['Corp Account'] = np.where(self.AP_df['Account'].isin(
            set(self.AP_df['Account'])), self.AP_df['Account'], self.AP_df['Offst.acct'])
        self.AP_df['Corp Account Name'] = self.AP_df.loc[:, 'Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("Local Account Name") if self.mydict2.get(x) is not None else None)

        self.AP_df['Doc. Date'] = np.where(self.AP_df['Doc. Date'].dt.year == 2200,
                                           self.AP_df['Pstng Date'], self.AP_df['Doc. Date'])
        self.AP_df['Group Account Number'] = self.AP_df.loc[:, 'Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account") if self.mydict2.get(x) is not None else None)
        self.AP_df['Group Account Name'] = self.AP_df.loc[:, 'Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account Name") if self.mydict2.get(
                x) is not None else None)
        self.AP_df['Group Account Name_Korean'] = self.AP_df.loc[:, 'Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account Korean Name") if self.mydict2.get(
                x) is not None else None)
        self.AP_df['Transaction Type'] = "Initial Accounting"
        self.AP_df['Category'] = self.AP_df['Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("reporting_line")
            if self.mydict2.get(x) is not None else None)
        # self.AP_df = self.AP_df[self.AP_df['Category'] != 'not applicable for ARAP']
        conds = [
            (self.AP_df["Customer"] == "") & (self.AP_df["Vendor"] == ""),
            (self.AP_df["Customer"] != "") & (self.AP_df["Vendor"] == ""),
        ]
        choices = [
            self.AP_df["Assign."],
            self.AP_df["Customer"],
        ]

        self.AP_df["Company_code"] = np.select(conds, choices, self.AP_df["Vendor"])
        self.AP_df["Company_code"] = (
            self.AP_df["Company_code"].astype(str).str.split(".").str.get(0)
        )
        self.AP_df["Company_name"] = self.AP_df["Company_code"].apply(
            lambda x: self.get_name(x)
        )

        cols_to_drop = ['Account', 'Offst.acct', 'Doc. Date', 'Customer', 'Clearing',
                        'LCurr', 'Assign.', 'Entry Date', 'Time', 'Sp.G/L ass', 'Vendor',
                        'Clrng doc.', 'ClgI', 'Entry date and time']
        self.AP_df = self.AP_df.drop(columns=cols_to_drop)
        self.AP_df['Deferred_Payment_Days'] = self.AP_df.apply(lambda row: self.get_days(row), axis=1)
        self.AP_df['Deferred_Payment_Days'] = self.AP_df['Deferred_Payment_Days'].apply(
            lambda x: int(str(x).split('.')[0]) if pd.notna(x) else 0)

        self.AP_df['Due Date'] = self.offset_date(self.AP_df['Pstng Date'],
                                                  self.AP_df['Deferred_Payment_Days'])
        self.AP_df['Overdue days'] = (
                pd.to_datetime(self.report_date) - pd.to_datetime(self.AP_df["Due Date"])).apply(
            lambda x: x.days)
        bins = [-1000, 0, 31, 61, 90, 20000]
        group_names = ['Before due date', '0-30', '31-60', '61-90', 'over 90 days']

        self.AP_df['Param'] = pd.cut(self.AP_df['Overdue days'], bins=bins, labels=group_names)
        self.AP_df = self.AP_df[self.AP_df['Category'] != 'Other AR']
        self.AP_df['Company_name'] = self.AP_df.apply(
            lambda row: self.translated.get(row['Company_code'], {}).get("Translated", row['Company_name']),
            axis=1
        )
        self.AP_df = self.AP_df[self.AP_df['Category'].isin(['AP','Other AP'])]
        return self.AP_df

    def make_ar_df(self):
        self.AR_df = self.AR_df. \
            drop(columns=self.AR_df.columns[self.AR_df.columns.str.contains("Unnamed") \
                                            | self.AR_df.columns.isin(['TTy', 'AccTy', ''])])
        self.AR_df['Rap Account'] = self.AR_df['Account'].apply(
            lambda x: self.mydict2.get(x).get("Rus Account") if \
                self.mydict2.get(x) is not None else None)
        self.AR_df = self.AR_df[~self.AR_df['Rap Account'].isin(['76.02.00', '60.01.00', '', None])]

        self.AR_df['Amount in LC'] = self.trailing_negative_numbers_(self.AR_df['Amount in LC'])
        self.AR_df[['Doc. Date', 'Pstng Date', 'Entry Date']] = self.AR_df[
            ['Doc. Date', 'Pstng Date', 'Entry Date']].applymap(
            lambda x: x.split(".")[2] + "-" + x.split(".")[1] + "-" + x.split(".")[0]).astype('datetime64[ns]')
        self.AR_df['Entry date and time'] = self.AR_df['Entry Date'].astype(str) + " " + self.AR_df['Time']
        self.AR_df['Entry date and time'] = self.AR_df['Entry date and time'].astype('datetime64[ns]')

        self.AR_df['DocumentNo'] = self.AR_df['DocumentNo'].str.split(".").str.get(0)
        self.AR_df['Sp.G/L ass'] = self.format_string(self.AR_df['Sp.G/L ass'])
        self.AR_df['Corp Account'] = np.where(self.AR_df['Account'].isin(
            set(self.AR_df['Account'])), self.AR_df['Account'], self.AR_df['Offst.acct'])
        self.AR_df['Corp Account Name'] = self.AR_df.loc[:, 'Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("Local Account Name") if self.mydict2.get(
                x) is not None else None)

        self.AR_df['Doc. Date'] = np.where(self.AR_df['Doc. Date'].dt.year == 2200,
                                           self.AR_df['Pstng Date'], self.AR_df['Doc. Date'])
        self.AR_df['Group Account Number'] = self.AR_df.loc[:, 'Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account") if self.mydict2.get(
                x) is not None else None)
        self.AR_df['Group Account Name'] = self.AR_df.loc[:, 'Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account Name") if self.mydict2.get(
                x) is not None else None)
        self.AR_df['Group Account Name_Korean'] = self.AR_df.loc[:, 'Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account Korean Name") if self.mydict2.get(
                x) is not None else None)
        self.AR_df['Transaction Type'] = "Initial Accounting"
        self.AR_df['Category'] = self.AR_df['Corp Account'].apply(
            lambda x: self.mydict2.get(x).get("reporting_line")
            if self.mydict2.get(x) is not None else None)
        # self.AR_df = self.AR_df[self.AR_df['Category'] != 'not applicable for ARAP']
        conds = [
            (self.AR_df["Customer"].str.len() == 0) & (self.AR_df["Vendor"].str.len() != 0),
            (self.AR_df["Customer"].str.len() == 0) & (self.AR_df["Vendor"].str.len() == 0),
        ]
        choices = [self.AR_df["Vendor"], "not applicable"]

        self.AR_df["Company_code"] = np.select(conds, choices, self.AR_df["Customer"])

        conds_2 = [
            (self.AR_df['Rap Account'].isin(['94.01.01', '94.01.02', '75.01.01', '58.01.03'])) &
            (pd.to_datetime(self.AR_df["Pstng Date"]).dt.year < 2020)

        ]

        choices_2 = [False]

        self.AR_df = self.AR_df[np.select(conds_2, choices_2, default=True)]
        cols_to_drop = (
            ['Account', 'Offst.acct', 'Doc. Date', 'Customer', 'Clearing', 'LCurr',
             'Assign.', 'Entry Date', 'Time', 'Sp.G/L ass', 'Vendor', 'Clrng doc.', 'ClgI',
             'Entry date and time']
        )
        self.AR_df = self.AR_df.drop(columns=cols_to_drop)
        self.AR_df["Company_code"] = (
            self.AR_df["Company_code"].astype(str).str.split(".").str.get(0)
        )
        self.AR_df["Company_name"] = self.AR_df["Company_code"].apply(
            lambda x: self.get_name(x)
        )

        self.AR_df['Deferred_Payment_Days'] = self.AR_df.apply(lambda row: self.get_days(row), axis=1)
        self.AR_df['Deferred_Payment_Days'] = self.AR_df['Deferred_Payment_Days'].apply(
            lambda x: int(str(x).split('.')[0]) if pd.notna(x) else 0)
        self.AR_df['Due Date'] = self.offset_date(self.AR_df['Pstng Date'],
                                                  self.AR_df['Deferred_Payment_Days'])

        self.AR_df['Overdue days'] = (
                pd.to_datetime(self.report_date) - pd.to_datetime(self.AR_df["Due Date"])).apply(
            lambda x: x.days)

        bins = [-1000, 0, 31, 61, 90, 20000]
        group_names = ['Before due date', '0-30', '31-60', '61-90', 'over 90 days']

        self.AR_df['Param'] = pd.cut(self.AR_df['Overdue days'], bins=bins, labels=group_names)

        self.AR_df['Company_name'] = self.AR_df.apply(
            lambda row: self.translated.get(row['Company_code'], {}).get("Translated", row['Company_name']),
            axis=1
        )

        self.AR_df = self.AR_df[self.AR_df['Category'].isin(['AR', 'Other AR'])]
        self.AR_df.reset_index(drop=True, inplace=True)
        return self.AR_df


if __name__ == '__main__':
    obj1 = Initials(
        AR_filepath=r'V:\Findep\Incoming\test\DevOps\ARAP Project\Project\Accounting Input Data\YTD07_2023\AR07YTD2023_02Aug2023.txt',
        report_date='07/31/2023'
    )
    print(obj1.make_ar_df().to_clipboard())



import pandas as pd
from custompacks import ExcelParser, TxtParser
import numpy as np


class GetCustomers:
    def __init__(self, filepath, value):

        self.dataframe = TxtParser(filepath, value).read_data()

        self.Mobility_Filepath = r'V:\Findep\Incoming\test\DevOps\References\Payment Terms\Status report 2.0.xlsm'
        self.MobilityPtShtName = 'Клиенты'

        self.AS_Filepath = r'V:\Findep\Incoming\test\DevOps\References\Payment Terms\Срок отсрочки платежа 210723.xlsx'
        self.ASPtShtNameRetail = 'Розница'
        self.ASPtShtNameOpt = 'ОПТ'

        self.MobilityPT = ExcelParser(self.Mobility_Filepath,
                                      self.MobilityPtShtName,
                                      'SAP код').read_data()

        self.ASPT_retail = ExcelParser(self.AS_Filepath,
                                       self.ASPtShtNameRetail,
                                       'Контрагент').read_data()

        self.ASPT_retail['Channel'] = "Retail"
        self.ASPT_retail = self.ASPT_retail.assign(Sap_code_and_channel=self.ASPT_retail['Контрагент.Код SAP'] + "_" +
                                                                        self.ASPT_retail['Channel'])
        self.ASPT_retail.drop_duplicates(subset=['Sap_code_and_channel'], keep='first', inplace=True)
        self.ASPT_retail['Отсрочка платежа'] = (self.ASPT_retail['Отсрочка платежа'].
                            astype(str).apply(lambda x: x.replace("None", '0')))
        self.ASPT_retail['Отсрочка платежа'] = self.ASPT_retail['Отсрочка платежа'].str.split(".").str.get(0).apply(
            lambda x: 0 if x == 'nan' else int(x))

        self.ASPT_opt = ExcelParser(self.AS_Filepath,
                                    self.ASPtShtNameOpt,
                                    'Контрагент').read_data()

        self.ASPT_opt['Channel'] = "WholeSales"
        self.ASPT_opt = self.ASPT_opt.assign(Sap_code_and_channel=self.ASPT_opt['Контрагент.Код SAP'] + "_" +
                                                                  self.ASPT_opt['Channel'])
        self.ASPT_opt.drop_duplicates(subset=['Sap_code_and_channel'], keep='first', inplace=True)

    def further_process(self):
        df = self.dataframe
        df = df[['KUNNR', 'LAND1', 'NAME1', 'NAME2', 'ORT01', 'PSTLZ', 'REGIO', 'SORTL', 'STRAS',
                 'TELF1', 'TELFX', 'XCPDK', 'ADRNR', 'MCOD1', 'MCOD2', 'MCOD3', "LOEVM"]]
        df = df[(~df['LAND1'].isin([None, "None", ])) & (df['LOEVM'].isin(['X', "None"]) == False) & (
                df["LAND1"].str.len() == 2)
                ]
        df['KUNNR'] = df['KUNNR'].astype(str).str.split(".").str.get(0)
        df = df[df['LAND1'].apply(lambda x: len(str(x)) == 2)]
        self.MobilityPT.loc[:, 'SAP код'] = self.MobilityPT.loc[:, 'SAP код'].astype(str).str.split(".").str.get(0)
        self.MobilityPT[r'Отсрочка платежа (дн.)'] = self.MobilityPT[r'Отсрочка платежа (дн.)'].astype(str)
        self.MobilityPT = self.MobilityPT.loc[:,
                          ['Сейлз', 'Менеджер', 'Клиент', 'ИНН', 'SAP код', 'Номер Договора аренды',
                           'Дата Договора аренды',
                           'Отсрочка платежа (дн.)', 'ЭДО', 'Статус клиента']]

        merged_df = pd.merge(df, self.MobilityPT, left_on='KUNNR', right_on='SAP код', how='left', sort=False)
        merged_df_with_retail = pd.merge(merged_df, self.ASPT_retail, left_on='KUNNR', right_on='Контрагент.Код SAP',
                                         how='left', sort=False)
        merged_df_with_ws = pd.merge(merged_df_with_retail, self.ASPT_opt, left_on='KUNNR',
                                     right_on='Контрагент.Код SAP',
                                     how='left', sort=False)
        cols_to_drop = ['Сейлз', 'Менеджер', 'Клиент', 'ИНН_x', 'SAP код', 'Номер Договора аренды',
                        'Дата Договора аренды', 'ЭДО', 'Статус клиента', 'Контрагент_x', 'ИНН_y', 'КПП_x',
                        'Код дилера_x', 'Контрагент.Код SAP_x', 'Основной договор_x', 'Ведение взаиморасчетов_x',
                        'Sap_code_and_channel_x', 'Контрагент_y', 'ИНН', 'КПП_y', 'Код дилера_y',
                        'Контрагент.Код SAP_y', 'Основной договор_y', 'Ведение взаиморасчетов_y',
                        'Sap_code_and_channel_y']
        merged_df_with_ws.drop(columns=cols_to_drop, inplace=True)
        f = lambda x: 0 if x in [None, "", np.nan, 'None'] else x
        merged_df_with_ws['Отсрочка платежа (дн.)'] = merged_df_with_ws['Отсрочка платежа (дн.)'].apply(f)
        merged_df_with_ws['Отсрочка платежа_x'] = merged_df_with_ws['Отсрочка платежа_x'].apply(f)
        merged_df_with_ws['Отсрочка платежа_x'] = merged_df_with_ws['Отсрочка платежа_x'].apply(
            lambda x: 0 if pd.isna(x) else x)
        merged_df_with_ws['Отсрочка платежа_y'] = merged_df_with_ws['Отсрочка платежа_y'].apply(f)
        cols = {
            "Отсрочка платежа_x": "Отсрочка платежа, дни, розница",
            "Отсрочка платежа_y": "Отсрочка платежа, дни, опт"
        }
        merged_df_with_ws.rename(columns=cols, inplace=True)

        @np.vectorize
        def custom_function(x: pd.Series, y: pd.Series, z: pd.Series):
            if pd.notna(x) and pd.isna(y):
                return "AS_" + x
            if pd.notna(x) and pd.notna(y):
                return "AS_" + y
            elif pd.isna(x) and pd.notna(y):
                return "AS_" + y
            elif z != 0:
                return "Mobility channel"

            elif pd.isna(x) and pd.isna(y):
                return 'not applicable'

        merged_df_with_ws['channel'] = custom_function(merged_df_with_ws['Channel_x'], merged_df_with_ws['Channel_y'],
                                                       merged_df_with_ws['Отсрочка платежа (дн.)'])
        merged_df_with_ws = merged_df_with_ws.drop(columns=['Channel_x', 'Channel_y'])

        return merged_df_with_ws


if __name__ == '__main__':
    parse_data = GetCustomers(filepath=r'V:\Findep\Incoming\test\DevOps\References\KNA 14072023.txt',
                              value='KUNNR')

    print(parse_data.further_process())



import time
import pandas as pd
import win32com.client as client
from custompacks.cleaninputdata.clean import DataframeCleaner
from pathlib import Path

from win32com.client import makepy
makepy.GenerateFromTypeLibSpec('Excel.Application')


pd.options.display.width = None

class ExcelParser:
    def __init__(self, *args: list[str:str:str]):
        self.filepath = args[0]
        self.sht = args[1]
        self.value = args[2]
    def read_data(self):
        start = time.perf_counter()
        try:
            xlapp = client.GetActiveObject("Excel.Application")
            wkb = xlapp.Workbooks.Open(self.filepath, ReadOnly=True, UpdateLinks=False)
            sht = wkb.Sheets[self.sht]
            used_rng = sht.UsedRange.Value
            df = pd.DataFrame(used_rng)
            wkb.Close(SaveChanges=False)
        except:
            xlapp = client.Dispatch('Excel.Application')
            wkb = xlapp.Workbooks.Open(self.filepath, ReadOnly=True, UpdateLinks=False)
            sht = wkb.Sheets[self.sht]
            used_rng = sht.UsedRange.Value
            df = pd.DataFrame(used_rng)
            wkb.Close(SaveChanges=False)
            xlapp.Quit()

        cleaner = DataframeCleaner(df)
        if self.value == 'Rus Account':
            cleaner.adj_by_row_index(value=self.value)
        else:
            cleaner.adj_by_row_index(value=self.value)
            cleaner.remove_duplicated_cols()
        end = time.perf_counter()
        print(
            f'Reading file {Path(self.filepath).name} '
            f'from file: {Path(__file__).__fspath__()} took {round((end - start), 2)} seconds'
        )
        return cleaner.df


class ExcelParser_retain_duplicates:
    def __init__(self, *args: list[str:str:str]):
        self.filepath = args[0]
        self.sht = args[1]
        self.value = args[2]

    def read_data(self):
        start = time.perf_counter()
        try:
            xlapp = client.GetActiveObject("Excel.Application")
            wkb = xlapp.Workbooks.Open(self.filepath, ReadOnly=True, UpdateLinks=False)
            sht = wkb.Sheets[self.sht]
            used_rng = sht.UsedRange.Value
            df = pd.DataFrame(used_rng)
            wkb.Close(SaveChanges=False)
        except:
            xlapp = client.Dispatch('Excel.Application')
            wkb = xlapp.Workbooks.Open(self.filepath, ReadOnly=True, UpdateLinks=False)
            sht = wkb.Sheets[self.sht]
            used_rng = sht.UsedRange.Value
            df = pd.DataFrame(used_rng)
            wkb.Close(SaveChanges=False)
            xlapp.Quit()

        cleaner = DataframeCleaner(df)
        if self.value == 'Rus Account':
            cleaner.adj_by_row_index(value=self.value)
        else:
            cleaner.adj_by_row_index(value=self.value)
        end = time.perf_counter()
        print(
            f'Reading file {Path(self.filepath).name} '
            f'from file: {Path(__file__).__fspath__()} took {round((end - start), 2)} seconds'
        )
        return cleaner.df


x = ExcelParser(
    r"V:\Findep\Incoming\test\DevOps\ARAP Project\Project\Accounting Input Data\YTD07_2023\Оборотно-сальдовая ведомость за January 2023 - July 2023 ООО  ХЕНДЭ МОБИЛИТИ ЛАБ.xls",
    'TDSheet',
    'Счет')

if __name__ == '__main__':

    print(x.read_data().info())


from custompacks import ExcelParser, MasterData
import numpy as np
import pandas as pd

pd.options.display.width = None
pd.options.mode.use_inf_as_na = True
class OBAdj:
    """
    This class shall be  used for getting OB adjustments from accounting files
    """

    def __init__(self, filepath, sht_name):
        self.dataframe = ExcelParser(filepath, sht_name, "Rus Account").read_data()
        self.dataframe = self.dataframe.iloc[:,slice(1,13)]
        self.dataframe['Corp Acc'] = self.dataframe['Corp Acc']. \
            astype(str).str.split(".").str.get(0)
        self.master_data = MasterData().further_process()
        self.master_data['Corp Acc'] = self.master_data['Corp Acc'].\
            astype(str).str.split(".").str.get(0)
        self.dataframe = self.dataframe[self.dataframe['Corp Acc'].isin(self.master_data['Corp Acc'])]

        self.mydict = self.master_data.drop_duplicates(subset='Rus Account', keep='first').set_index("Rus Account").T.to_dict()
        self.mydict2 = self.master_data.set_index('Corp Acc').T.to_dict()

    def further_process(self):
        self.dataframe.columns = ['col' + str(x) for x in range(len(self.dataframe.columns))]
        cols_to_be = [
            'Rus Account', 'Corp Acc', 'RUS_Text', 'ENG_Text', 'Initials_Dr', 'Initials_Cr',
            'OB_adj_Dr', 'OB_adj_Cr', 'Accruals_Dr', 'Accruals_Cr', 'CB_Dr', 'CB_Cr', 'Acc_Group']
        self.dataframe = self.dataframe.rename(columns=dict(zip(self.dataframe.columns, cols_to_be)))
        merged_df = pd.merge(self.dataframe, self.master_data, on='Corp Acc', how='left',
                             sort=False)
        return merged_df

    def reveal_ob_adjustments(self):
        df = self.further_process().copy()

        @np.vectorize
        def check_if_none(x, y):
            if x in [0, None, ""] and y in [0, None, ""]:
                return False
            else:
                return True

        df = df[check_if_none(df['OB_adj_Dr'], df['OB_adj_Cr'])]

        df.rename(columns={'Corp Acc': 'Corp Account',
                           'ENG_Text': 'Corp Account Name',
                           'Rus Account_y': 'Rap Account'
                           }, inplace=True)

        @np.vectorize
        def func1(x, y):
            if x in [None, "None", '0.0',0] and y not in [None, "None", '0.0',0]:
                return y
            elif x not in [None, "None", '0.0',0] and y in [None, "None", '0.0',0]:
                return x

        df['Amount in LC'] = func1(df['OB_adj_Dr'], df['OB_adj_Cr'])
        cols_to_select = ['Corp Account', 'Corp Account Name', 'Rap Account', 'Amount in LC', 'Category','reporting_line']
        df = df[cols_to_select]
        df['Transaction Type'] = 'Opening Balance adjustment'
        df['Pstng Date'] = pd.to_datetime('01/01/2023').date()
        df['Param'] = 'Before due date'
        df['Text'] = 'This is opening balance adjustment at the beginning of the 2023 year'
        df['Amount in LC'] = df['Amount in LC'].astype(str).str.split(".").str.get(0).astype(float)

        df.loc[:, "Group Account Number"] = df.loc[:, "Corp Account"] \
            .apply(lambda x: self.mydict2.get(x).get("Consolidation Account") if self.mydict2.get(x) else x)
        df.loc[:, "Group Account Name"] = df.loc[:, "Corp Account"] \
            .apply(lambda x: self.mydict2.get(x).get("Consolidation Account Name") if self.mydict2.get(x) else x)
        df.loc[:, "Group Account Name_Korean"] = df.loc[ :, "Corp Account" ].apply(
            lambda x: self.mydict2.get(x).get("Consolidation Account Korean Name") if self.mydict2.get(x) else x)

        return df

    def reveal_ob_adj_ARAP(self):
        df = self.reveal_ob_adjustments().copy()
        df = df[df['reporting_line'].isin(['AR','AP','Other AR', 'Other AP'])]
        df['Category'] = df['reporting_line']
        df['Amount in LC'] = df['Amount in LC'].astype(str).str.split(".").str.get(0).astype(float)

        conds = [
            df['reporting_line'].isin(["AP", "Other AP"])
        ]

        choices = [
            df['Amount in LC'] * -1
        ]

        df['Amount in LC'] = np.select(conds, choices, default=df['Amount in LC'])


        return df



if __name__ == '__main__':
    x = OBAdj(r'V:\Accounting\Work\Мерц\2023\3 квартал\Июль 2023\Отчетность\Detail_July_2023.xlsx',
              'ОСВ_Июль_2023')
    print(x.reveal_ob_adj_ARAP().to_clipboard())



from custompacks import ExcelParser
import numpy as np
import pandas as pd

class MasterData:
    """"""
    def __init__(self):
        self.tb = ExcelParser(r'V:\Findep\Incoming\test\DevOps\References\HMCIS TB structure_2023.xlsx',
                              'TB_01_07_2023', 'Local Account Code').read_data()
        self.pl = ExcelParser(r'V:\Findep\Incoming\test\DevOps\References\HMCIS PL structure_2023.xlsx',
                              'Sheet1', 'Local Account Code').read_data()
        self.bs = ExcelParser(r'V:\Findep\Incoming\test\DevOps\References\HMCIS BS structure_2023.xlsx',
                              'Sheet1', 'Local Account Code').read_data()
        self.osv = ExcelParser(r"V:\Findep\Incoming\test\DevOps\References\HMCIS OSV structure_2023.xlsx",
                               'Sheet1',
                               'Rus Account').read_data()
        self.korean_reference = ExcelParser(
            r"V:\Findep\Incoming\test\DevOps\HSE1_CoA\Current CoA_2023.xlsx",
            'Sheet1',
            'col1').read_data()
        self.korean_reference[self.korean_reference.columns[8]] = \
            self.korean_reference[self.korean_reference.columns[8]].astype(str).str.split(".").str.get(0)

    def clean_osv(self):
        self.osv['Rus Account'] = self.dates_to_strings(self.osv['Rus Account'].astype(str))
        self.osv['Corp Acc'] = self.osv['Corp Acc'].astype(str).str.split('.').str.get(0)
        self.osv = self.osv.loc[:, ['Rus Account', 'Corp Acc', 'Text']]
        return self.osv

    def clean_bs(self):
        self.bs['Consolidation Account Code'] = self.bs['Consolidation Account Code']. \
            astype(str).str.split(".").str.get(0)
        conds_bs = [(self.bs['Consolidation Account Code'].str.len() == 5) |
                    (self.bs['Consolidation Account Code'].str.len() == 3)]

        choices_bs = [self.bs['Consolidation Account Code']]

        self.bs['FS Line'] = np.select(conds_bs, choices_bs, default=None)
        self.bs['FS Line'] = self.bs['FS Line'].ffill()
        self.bs.drop_duplicates(subset=['Consolidation Account Code'], keep='first', inplace=True)
        mydict = self.bs[['Consolidation Account Code', 'Account Name']].set_index(
            'Consolidation Account Code'
        ).T.to_dict()
        self.bs['FS Line Name'] = self.bs['FS Line'].apply(
            lambda x: mydict.get(x).get('Account Name') if mydict.get(x) is not None else x)
        self.bs = self.bs.loc[:, ['Account Tree',
                                  'Local Account Code', 'Local Account Name',
                                  'FS Line', 'FS Line Name']]
        self.bs = self.bs[pd.notna(self.bs.loc[:, 'Local Account Code'])]
        self.bs['Local Account Code'] = self.bs['Local Account Code'].astype(str).str.split('.').str.get(0)
        return self.bs

    def clean_tb(self):
        self.tb['Local Account Code'] = self.tb['Local Account Code'].astype(str).str.split('.').str.get(0)
        self.tb = self.tb[['Local Account Code', 'Local Account Name', 'Consolidation Account',
                           'Consolidation Account Name']]
        return self.tb

    def clean_pl(self):
        self.pl['Consolidation Account Code'] = (self.pl['Consolidation Account Code'].astype(str).
                                                 str.split('.').str.get(0))

        conds = [(self.pl['Consolidation Account Code'].str.len() == 5) |
                 (self.pl['Consolidation Account Code'].str.len() == 3)]

        choices = [self.pl['Consolidation Account Code']]

        self.pl['FS Line'] = np.select(conds, choices, default=None)

        self.pl['FS Line'] = self.pl['FS Line'].ffill()
        self.pl.drop_duplicates(subset=['Consolidation Account Code'], keep='first', inplace=True)

        mydict = (self.pl[['Consolidation Account Code', 'Account Name']].
                  set_index('Consolidation Account Code').T.to_dict())
        self.pl['FS Line Name'] = self.pl['FS Line'].apply(
            lambda x: mydict.get(x).get('Account Name')
            if mydict.get(x) is not None else x)
        self.pl = self.pl.loc[:, ['Local Account Code', 'Local Account Name', 'FS Line', 'FS Line Name']]
        self.pl = self.pl[pd.notna(self.pl.loc[:, 'Local Account Code'])]
        self.pl['Local Account Code'] = self.pl['Local Account Code'].astype(str).str.split('.').str.get(0)

        return self.pl

    def further_process(self):

        concatenated_df = pd.concat([self.clean_bs(), self.clean_pl()], ignore_index=False)
        concatenated_df.sort_values(by='Local Account Code', ascending=True, inplace=True)

        combined_1 = pd.merge(self.clean_osv(), self.clean_tb(), left_on='Corp Acc',
                              right_on='Local Account Code', sort=False, how='left')

        combined_1['FS Line'] = combined_1['Consolidation Account'].astype(str).str[:5]

        mydict2 = (concatenated_df[['FS Line', 'FS Line Name']].drop_duplicates().
                   set_index("FS Line").T.to_dict())

        combined_1['FS Line Name'] = combined_1['FS Line'].apply(
            lambda x: mydict2.get(x).get('FS Line Name') if mydict2.get(x) is not None else x)

        conds = [
            combined_1['Corp Acc'].isin(['11100101']),
            combined_1['Corp Acc'].isin(['11100100']),
            combined_1['Corp Acc'].isin(['11100097']),
            combined_1['Corp Acc'].isin(['A21009013']),
            combined_1['Corp Acc'].isin(['61000302']),
            combined_1['Corp Acc'].isin(['62000206', 'A62000206', 'A61000306']),
        ]

        choices_1 = ['11130040', '11102191', '11130040', '21116390', '62002010', '61002010']
        choices_2 = ['Ordinary Account (Local Currency)', 'Cash Equivalents_Other Deposits_Others_Local Currency',
                     'Ordinary Account (Local Currency)', 'Other AP_Taxes and Dues_Others',
                     'Loss on Foreign Currency Translations_Operating',
                     'Loss on Foreign Currency Translations_Operating',
                     ]
        choices_3 = ['11130', '11102', '11130', '21116',
                     '62002',
                     '62002']
        choices_4 = ['Ordinary Account (Local Currency)', 'Cash Equivalents',
                     'Ordinary Account (Local Currency)', 'Other AP_Taxes and Dues',
                     'Loss on Foreign Currency Translations',
                     'Loss on Foreign Currency Translations'
                     ]

        combined_1['Consolidation Account'] = np.select(conds, choices_1, default=combined_1['Consolidation Account'])
        combined_1['Consolidation Account Name'] = np.select(conds, choices_2,
                                                             default=combined_1['Consolidation Account Name'])
        combined_1['FS Line'] = np.select(conds, choices_3, default=combined_1['FS Line'])
        combined_1['FS Line Name'] = np.select(conds, choices_4, default=combined_1['FS Line Name'])
        combined_1['Category'] = combined_1['Consolidation Account'].apply(lambda x: str(x)[:4])
        combined_1['reporting_line'] = pd.cut(combined_1['Category'],
                                              ['1110', '1120', '1139', '1150', '1160', '1180', '1200',
                                               '1220', '1250', '1260', '1270', '1400', '2109', '2111',
                                               '2112', '2113', '2140', '2160', '2180', '2260', '2270',
                                               '2290', '3100', '3500', '4100', '4108', '4200', '4202', '4300',
                                               '5100', '5200', '6100', '6200', '7100', '7200',
                                               '7400', '7900', '8000'],
                                              labels=['Cash and Cash Equivalents',
                                                      'Other Assets, Current',
                                                      'AR',
                                                      "Other AR",
                                                      'Inventories',
                                                      'Short-Term Investments',
                                                      None,
                                                      'Long-Term Loans and Receivables',
                                                      'PPE',
                                                      None,
                                                      'Intangible Assets',
                                                      'Right-of-use Asset',
                                                      "AP",
                                                      "Other AP",
                                                      "Other AP",
                                                      None,
                                                      'Other Liabilities, Current',
                                                      '(Current)Provision',
                                                      '(Current)Lease Liabilities',
                                                      'Provision, Non-Current',
                                                      'Deferred Tax Liabilities',
                                                      'Lease Liabilities, Non-Current',
                                                      'Capital stock',
                                                      'Retained earnings',
                                                      'Sales Revenue',
                                                      'Sales Adjustment_incentive',
                                                      'COGS',
                                                      'Other COGS',
                                                      None,
                                                      'SG&A expenses',
                                                      None,
                                                      'Other operating income',
                                                      'Other operating expenses',
                                                      'Financial income',
                                                      'Financial expenses',
                                                      'Net Income_NCI',
                                                      'Income tax expenses',

                                                      ],
                                              right=False,
                                              ordered=False)

        conds = [
            (combined_1['reporting_line'] == 'PPE') & (combined_1['Consolidation Account Name'].str.contains("Dep")),
            (combined_1['reporting_line'] == 'Right-of-use Asset') & (
                combined_1['Consolidation Account Name'].str.contains("Dep"))
        ]
        choices = [
            'PPE_Accumulated Depreciation',
            'Right-of-use Asset_Accumulated Depreciation'
        ]
        combined_1['reporting_line'] = np.select(conds, choices, default=combined_1['reporting_line'])

        conds_2 = [
            (combined_1['Rus Account'].astype(str).str.startswith("55")) & (pd.isna(combined_1['reporting_line'])),
            (combined_1['Rus Account'].astype(str).str.startswith("68.02")) & (pd.isna(combined_1['reporting_line']))
        ]

        choices_6 = [
            '1110',
            '2142',
        ]

        choices_7 = [
            'Cash and Cash Equivalents',
            'Other Liabilities, Current'
        ]

        choices_8 = [
            '11102',
            '21421'
        ]

        choices_9 = [
            'Cash Equivalents',
            'VAT Payables'
        ]

        combined_1['Category'] = np.select(conds_2, choices_6, default=combined_1['Category'])
        combined_1['reporting_line'] = np.select(conds_2, choices_7, default=combined_1['reporting_line'])
        combined_1['FS Line'] = np.select(conds_2, choices_8, default=combined_1['FS Line'])
        combined_1['FS Line Name'] = np.select(conds_2, choices_9, default=combined_1['FS Line Name'])

        special_cond = [
            combined_1['Category'].str.startswith(('1', '2', '3')),
            combined_1['Category'].str.startswith(('4', '5', '6', '7')),
        ]
        choices_5 = [
            'bs',
            'pl',
        ]
        combined_1['accounting group'] = np.select(special_cond, choices_5, default='')
        combined_1['Consolidation Account'] = (
            combined_1['Consolidation Account'].astype(str).str.split(".").str.get(0))

        korean_ref = self.korean_reference.set_index(self.korean_reference.columns[8]).T.to_dict()

        combined_1['Consolidation Account Korean Name'] = \
            combined_1['Consolidation Account'].apply(lambda x: korean_ref.get(x).get('계정명')
            if korean_ref.get(x) else None)

        return combined_1

    @staticmethod
    @np.vectorize
    def dates_to_strings(col: pd.Series):
        if len(col) == 8:
            return col
        elif col in [None, "None"]:
            return None
        elif len(col) == 5 or len(col) == 7 or len(col) == 9:
            return col
        else:
            try:
                return pd.to_datetime(col, dayfirst=False).strftime('%d.%m.%y')
            except ValueError:
                pass


if __name__ == '__main__':
    x = MasterData()
    # print(x.further_process().to_clipboard())
    x.clean_tb().to_clipboard()



from custompacks import ExcelParser, MasterData, ExcelParser_retain_duplicates
import pandas as pd
import numpy as np

CoA_object = MasterData().further_process()

mydict2_object = CoA_object.set_index('Corp Acc').T.to_dict()


@np.vectorize
def offset_date(x, y):
    return x + pd.offsets.Day(y)


class Df1Parser:
    def __init__(self, filepath, sht, index, report_date):
        self.report_date = report_date
        self.df1 = ExcelParser_retain_duplicates(filepath, sht, index).read_data()

    def further_process_df1(self):
        self.df1.columns = ['Счет', 'Субконто 1', 'None', 'Субконто 2', 'Субконто 3.Дата', 'Нач. Остаток Дт',
                            'Нач. Остаток Кт', 'Обороты Дт', 'Обороты Кт', 'Кон. Остаток Дт', 'Кон. Остаток Кт',
                            'Количество записей']
        self.df1 = self.df1[~self.df1['Счет'].isin(['Total','', None])]
        conds = [
            ~self.df1['Кон. Остаток Дт'].isin(['None']),
            ~self.df1['Кон. Остаток Кт'].isin(['None'])
        ]

        choices = [
            True, True
        ]

        self.df1 = self.df1[np.select(conds, choices, default=False)]
        params = {'60.01': 'A21000101', '60.02': 'A21000106', '62.01': 'A11010601'}
        self.df1['Corp Account'] = self.df1['Счет'].apply(lambda element: params.get(element))
        self.df1['Company_code'] = '1C Counterparty'
        self.df1['Кон. Остаток Дт'] = self.df1['Кон. Остаток Дт'].apply(
            lambda x: float(x) if x not in ['None', None] else 0)
        self.df1['Кон. Остаток Кт'] = self.df1['Кон. Остаток Кт'].apply(
            lambda x: float(x) * -1 if x not in ['None', None] else 0)

        self.df1 = self.df1.rename(columns=
                                   {"Субконто 1": "Company_name",
                                    'Субконто 2': 'Text',
                                    'Счет': 'Rap Account',
                                    'Субконто 3.Дата': 'Pstng Date',
                                    })

        self.df1['Amount in LC'] = self.df1[['Кон. Остаток Дт', 'Кон. Остаток Кт']].sum(axis=1)
        self.df1 = self.df1.drop(columns=['Кон. Остаток Дт', 'Кон. Остаток Кт', 'Количество записей',
                                          'Нач. Остаток Дт', 'Нач. Остаток Кт', 'Обороты Дт', 'Обороты Кт'])

        self.df1['Category'] = self.df1['Corp Account'].apply(
            lambda x: mydict2_object.get(x).get('reporting_line') if mydict2_object.get(x) else x)
        self.df1['Corp Account Name'] = self.df1['Corp Account'].apply(
            lambda x: mydict2_object.get(x).get('Local Account Name') if mydict2_object.get(x) else x)
        self.df1['Transaction Type'] = 'HML'
        self.df1['Pstng Date'] = pd.to_datetime(self.report_date).date()
        self.df1 = self.df1.drop(columns=['None'])
        self.df1.loc[:, "Group Account Number"] = self.df1.loc[:, "Corp Account"] \
            .apply(lambda x: mydict2_object.get(x).get("Consolidation Account") if mydict2_object.get(x) else x)
        self.df1.loc[:, "Group Account Name"] = self.df1.loc[:, "Corp Account"] \
            .apply(lambda x: mydict2_object.get(x).get("Consolidation Account Name") if mydict2_object.get(x) else x)
        self.df1.loc[:, "Group Account Name_Korean"] = self.df1.loc[
                                                       :, "Corp Account"
                                                       ].apply(
            lambda x: mydict2_object.get(x).get("Consolidation Account Korean Name") if mydict2_object.get(x) else x)

        self.df1['Deferred_Payment_Days'] = 0
        self.df1['Due Date'] = offset_date(self.df1["Pstng Date"],
                                           self.df1["Deferred_Payment_Days"])
        self.df1["Overdue days"] = (
                pd.to_datetime(self.report_date)
                - pd.to_datetime(self.df1["Due Date"])
        ).apply(lambda x: x.days)
        self.df1['Param'] = 'Before due date'
        self.df1 = self.df1[self.df1['Amount in LC']!=0]

        return self.df1


class Df2Parser:
    def __init__(self, filepath, sht, index, report_date):
        self.report_date = report_date
        self.df1 = ExcelParser_retain_duplicates(filepath, sht, index).read_data()

        self.df1.columns = ['Счет', 'Субконто 1', 'None', 'Субконто 2', 'Субконто 3.Дата', 'Нач. Остаток Дт',
                            'Нач. Остаток Кт', 'Обороты Дт', 'Обороты Кт', 'Кон. Остаток Дт', 'Кон. Остаток Кт',
                            'Количество записей']
        self.df1.dropna(how='all', axis=1, inplace=True)
        self.df1.dropna(how='all', axis=0, inplace=True)
        self.df1 = self.df1[self.df1['Количество записей']==1]

    def further_process_df1(self):
        conds = [
            ~self.df1['Кон. Остаток Дт'].isin(['None']),
            ~self.df1['Кон. Остаток Кт'].isin(['None'])
        ]

        choices = [
            True, True
        ]

        self.df1 = self.df1[np.select(conds, choices, default=False)]
        params = {'76.09': 'A11011206', '76.29': 'A11011206'}
        self.df1['Corp Account'] = self.df1['Счет'].apply(lambda element: params.get(element))
        self.df1['Company_code'] = '1C Counterparty'
        self.df1['Кон. Остаток Дт'] = self.df1['Кон. Остаток Дт'].apply(
            lambda x: float(x) if x not in ['None', None] else 0)
        self.df1['Кон. Остаток Кт'] = self.df1['Кон. Остаток Кт'].apply(
            lambda x: float(x) if x not in ['None', None] else 0)

        self.df1 = self.df1.rename(columns=
                                   {"Субконто 1": "Company_name",
                                    'Субконто 2': 'Text',
                                    'Счет': 'Rap Account',
                                    'Субконто 3.Дата': 'Pstng Date',
                                    })
        #
        self.df1['Amount in LC'] = self.df1[['Кон. Остаток Дт', 'Кон. Остаток Кт']].sum(axis=1)
        self.df1 = self.df1.drop(columns=['Кон. Остаток Дт', 'Кон. Остаток Кт', 'Количество записей',
                                          'Нач. Остаток Дт', 'Нач. Остаток Кт', 'Обороты Дт', 'Обороты Кт'])

        self.df1['Category'] = self.df1['Corp Account'].apply(
            lambda x: mydict2_object.get(x).get('reporting_line') if mydict2_object.get(x) else x)
        self.df1['Corp Account Name'] = self.df1['Corp Account'].apply(
            lambda x: mydict2_object.get(x).get('Local Account Name') if mydict2_object.get(x) else x)
        self.df1['Transaction Type'] = 'HML'
        self.df1['Pstng Date'] = pd.to_datetime(self.report_date).date()
        self.df1.loc[:, "Group Account Number"] = self.df1.loc[:, "Corp Account"] \
            .apply(lambda x: mydict2_object.get(x).get("Consolidation Account") if mydict2_object.get(x) else x)
        self.df1.loc[:, "Group Account Name"] = self.df1.loc[:, "Corp Account"] \
            .apply(lambda x: mydict2_object.get(x).get("Consolidation Account Name") if mydict2_object.get(x) else x)
        self.df1.loc[:, "Group Account Name_Korean"] = self.df1.loc[
                                                       :, "Corp Account"
                                                       ].apply(
            lambda x: mydict2_object.get(x).get("Consolidation Account Korean Name") if mydict2_object.get(x) else x)
        self.df1['Deferred_Payment_Days'] = 0
        self.df1['Due Date'] = offset_date(self.df1["Pstng Date"],
                                           self.df1["Deferred_Payment_Days"])
        self.df1["Overdue days"] = (
                pd.to_datetime(self.report_date)
                - pd.to_datetime(self.df1["Due Date"])
        ).apply(lambda x: x.days)
        self.df1['Param'] = 'Before due date'
        return self.df1


class Df3Parser:
    def __init__(self, filepath, sht, index, report_date):
        self.report_date = report_date
        self.df1 = ExcelParser_retain_duplicates(filepath, sht, index).read_data()

    def further_process_df1(self):
        self.df1.columns = ['Счет', 'Наименование счета', 'Сальдо на начало периода Дт',
                            'Сальдо на начало периода Кт', 'Обороты за период Дт', 'Обороты за период Кт',
                            'Сальдо на конец периода Дт', 'Сальдо на конец периода Кт']
        self.df1 = self.df1[self.df1['Счет'].isin(['68.01.1', '68.02', '69.01', '69.11', '69.09'])]
        #
        self.df1['Сальдо на конец периода Кт'] = self.df1['Сальдо на конец периода Кт'].apply(
            lambda x: float(str(x)) * -1 if x not in ['None', None] else 0)
        #
        self.df1['Сальдо на конец периода Дт'] = self.df1['Сальдо на конец периода Дт'].apply(
            lambda x: float(str(x)) if x not in ['None', None] else 0)
        #
        self.df1['Amount in LC'] = self.df1[['Сальдо на конец периода Дт', 'Сальдо на конец периода Кт']].sum(axis=1)
        self.df1 = self.df1.rename(columns={'Счет': 'Rap Account'})
        #
        @np.vectorize
        def define_corp_acc(x):
            if x == '68.01.1':
                return 'A21009007'
            elif x == '68.02':
                return 'A11013005'
            elif x == '69.01':
                return 'A21009012'
            elif x == '69.11':
                return 'A21009020'
            elif x == '69.09':
                return 'A21009013'
        #
        self.df1['Corp Account'] = define_corp_acc(self.df1['Rap Account'])
        self.df1['Pstng Date'] = pd.to_datetime(self.report_date).date()
        #
        cols_to_drop = ['Наименование счета', 'Сальдо на начало периода Дт',
                        'Сальдо на начало периода Кт',
                        'Обороты за период Дт', 'Обороты за период Кт', 'Сальдо на конец периода Дт',
                        'Сальдо на конец периода Кт']
        #
        self.df1 = self.df1.drop(columns=cols_to_drop)
        self.df1['Category'] = self.df1['Corp Account'].apply(
            lambda x: mydict2_object.get(x).get('reporting_line') if mydict2_object.get(x) else x)
        self.df1 = self.df1[self.df1['Category'].isin(["Other AP","AP","Other AR","AR"])]
        self.df1['Corp Account Name'] = self.df1['Corp Account'].apply(
            lambda x: mydict2_object.get(x).get('Local Account Name') if mydict2_object.get(x) else x)
        self.df1['Transaction Type'] = 'HML'
        #
        self.df1.loc[:, "Group Account Number"] = self.df1.loc[:, "Corp Account"] \
            .apply(lambda x: mydict2_object.get(x).get("Consolidation Account") if mydict2_object.get(x) else x)
        self.df1.loc[:, "Group Account Name"] = self.df1.loc[:, "Corp Account"] \
            .apply(lambda x: mydict2_object.get(x).get("Consolidation Account Name") if mydict2_object.get(x) else x)
        self.df1.loc[:, "Group Account Name_Korean"] = self.df1.loc[
                                                       :, "Corp Account"
                                                       ].apply(
            lambda x: mydict2_object.get(x).get("Consolidation Account Korean Name") if mydict2_object.get(x) else x)
        #
        self.df1['Deferred_Payment_Days'] = 0
        self.df1['Due Date'] = offset_date(self.df1["Pstng Date"],
                                           self.df1["Deferred_Payment_Days"])
        self.df1["Overdue days"] = (
                pd.to_datetime(self.report_date)
                - pd.to_datetime(self.df1["Due Date"])
        ).apply(lambda x: x.days)
        self.df1['Param'] = 'Before due date'

        return self.df1


if __name__ == '__main__':
    x = Df1Parser(
        filepath=r'V:\Findep\Incoming\test\DevOps\ARAP Project\Project\Accounting Input Data\YTD07_2023\07YTD2023_60_62.xlsx',
        sht='TDSheet', index='Счет', report_date='06/30/2023')

    y = Df2Parser(
        filepath=r'C:\Users\slalnazarov\Desktop\08YTD2023_76.xlsx', index='Счет',
        sht='TDSheet', report_date='06/30/2023')

    z = Df3Parser(
        filepath=r'V:\Findep\Incoming\test\DevOps\ARAP Project\Project\Accounting Input Data\YTD07_2023\Оборотно-сальдовая ведомость за January 2023 - July 2023 ООО  ХЕНДЭ МОБИЛИТИ ЛАБ.xls',
        sht='TDSheet', index='Счет',
        report_date='06/30/2023')

    print(z.further_process_df1().to_clipboard())



import xlwings as xw
from xlwings import constants as cs

xw.Book(r'V:\Findep\Incoming\test\DevOps\updated_ARAP\updated_ARAP.xlsm').set_mock_caller()


class MakePivots:
    def __init__(self, datasource_sheet: str = None):
        self.datasource_sheet = datasource_sheet
        wb = xw.Book.caller()
        self.ws = wb.sheets[self.datasource_sheet]
        self.wkb = wb

    def clear_pt(self, ws: str = None):
        for pt in self.wkb.sheets[ws].api.PivotTables():
            pt.TableRange2.Clear()

    def create_pt_sheet(self, pt_sheet_name: str = None):
        self.wkb.sheets.add(name=pt_sheet_name, after=self.wkb.sheets.count)

    def create_pt_table(self, pt_sheet_name: str = None, pt_name: str = None, exclude_items: tuple = None):
        target_rng = self.wkb.sheets[self.datasource_sheet].range("c11").current_region.api
        pt_cache = self.wkb.api.PivotCaches().Create(1,
                                                     self.wkb.sheets[self.datasource_sheet].api.Range(
                                                         target_rng.Address))

        pt = pt_cache.CreatePivotTable(self.wkb.sheets[pt_sheet_name].api.Range("a2"), pt_name)
        self.insert_pt_field(pt)
        pt.PivotFields("Category").Orientation = 3
        pt.PivotFields("Category").Position = 1
        pt.PivotFields("Category").PivotItems(exclude_items[0]).Visible = False
        pt.PivotFields("Category").PivotItems(exclude_items[1]).Visible = False
        pt.PivotFields("Category").PivotItems(exclude_items[2]).Visible = False

        pt.PivotFields("Group Account Number").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.PivotFields("Group Account Name").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.PivotFields("Corp Account").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.PivotFields("Corp Account Name").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.PivotFields("Company_code").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.PivotFields("Company_name").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.PivotFields("Pstng Date").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.PivotFields("Deferred_Payment_Days").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.PivotFields("Due Date").AutoSort(Order=cs.SortOrder.xlDescending, Field="Sum of Amount in LC")
        pt.TableStyle2 = "PivotStyleDark12"

        self.wkb.sheets[pt_sheet_name]["a4"].current_region.api.Font.Name = "Hyundai Sans Text"
        self.wkb.sheets[pt_sheet_name]["a4"].current_region.api.HorizontalAlignment = cs.Constants.xlLeft
        self.wkb.sheets[pt_sheet_name]["a4"].current_region.api.VerticalAlignment = cs.Constants.xlTop
        self.wkb.sheets[pt_sheet_name]["A:H"].api.ColumnWidth = 25
        # self.wkb.sheets[pt_sheet_name]["D:E"].api.ColumnWidth = 25
        # self.wkb.sheets[pt_sheet_name]["T:U"].api.ColumnWidth = 30
        # self.wkb.sheets[pt_sheet_name]["H:H"].api.ColumnWidth = 20
        self.wkb.sheets[pt_sheet_name]["I:N"].api.ColumnWidth = 15
        self.wkb.api.ShowPivotTableFieldList = False

        return pt

    @staticmethod
    def insert_pt_field(pt):
        field_rows = {"Consolidation acc": pt.PivotFields("Group Account Number"),
                      "Consolidation acc name": pt.PivotFields("Group Account Name"),
                      "Local Account": pt.PivotFields("Corp Account"),
                      "Local Account Name": pt.PivotFields("Corp Account Name"),
                      "Company code": pt.PivotFields("Company_code"), "Company Name": pt.PivotFields("Company_name"),
                      "Pstng Date": pt.PivotFields("Pstng Date"),
                      "Deferred payment_days": pt.PivotFields("Deferred_Payment_Days"),
                      "Due Date": pt.PivotFields("Due Date")}

        field_values = {"Total Amount in RUB": pt.PivotFields("Amount in LC"),
                        "Group Acc number": pt.PivotFields("Amount in LC")}
        # field_values["Total Amount in KRW"] = pt.PivotFields("Amt in KRW")
        # field_values["Group Acc number_1"] = pt.PivotFields("Amt in KRW")

        field_cols = {"bins": pt.PivotFields("Param")}

        field_rows["Consolidation acc"].Orientation = 1
        field_rows["Consolidation acc"].Position = 1

        field_rows["Consolidation acc name"].Orientation = 1
        field_rows["Consolidation acc name"].Position = 2

        field_rows["Local Account"].Orientation = 1
        field_rows["Local Account"].Position = 3

        field_rows["Local Account Name"].Orientation = 1
        field_rows["Local Account Name"].Position = 4

        field_rows["Company Name"].Orientation = 1
        field_rows["Company Name"].Position = 5

        field_rows["Company code"].Orientation = 1
        field_rows["Company code"].Position = 6

        field_rows["Pstng Date"].Orientation = 1
        field_rows["Pstng Date"].Position = 7

        field_rows["Deferred payment_days"].Orientation = 1
        field_rows["Deferred payment_days"].Position = 8

        field_rows["Due Date"].Orientation = 1
        field_rows["Due Date"].Position = 9

        field_values["Group Acc number"].Orientation = 4
        field_values["Group Acc number"].Function = -4157
        field_values["Group Acc number"].NumberFormat = "#,##0"
        # field_values["Group Acc number_1"].Orientation = 4
        # field_values["Group Acc number_1"].Function = -4157
        # field_values["Group Acc number_1"].NumberFormat = "#,##0"

        field_cols["bins"].Orientation = 2
        field_cols["bins"].Position = 1
        field_cols["bins"].PivotItems("Before due date").Position = 1



import pandas as pd
import time
from pathlib import Path
from custompacks import DataframeCleaner

pd.options.display.width = None

class TxtParser:
    def __init__(self, filepath: str = None, idx_value: str = None):
        self.filepath = filepath
        self.idx_value = idx_value
        self.dataframe = None

    def read_data(self):
        start = time.perf_counter()
        self.dataframe = pd.read_csv(self.filepath, encoding='cp1251', sep = '\t', dtype=str)
        self.dataframe = self.dataframe.iloc[:, 0].str.split("|", expand=True)
        cleaner = DataframeCleaner(self.dataframe)
        cleaner.adj_by_row_index(value=self.idx_value)
        cleaner.remove_duplicated_cols()
        end = time.perf_counter()
        print(f'Reading file {Path(self.filepath).name} from python file: {Path(__file__).name} took {round((end - start), 2)} seconds')

        return cleaner.df


if __name__ == '__main__':
    x = TxtParser(r'V:\Findep\Incoming\test\DevOps\ARAP Project\Project\Accounting Input Data\YTD07_2023\AP07YTD2023_02Aug2023.txt',
                  "Account")

    print(x.read_data())


import pandas as pd
from custompacks import ExcelParser
import numpy as np


class GetTb:

    def __init__(self,filepath, sht_name, index):
        self.filepath = filepath
        self.sht_name = sht_name
        self.index = index
        self.df = ExcelParser(self.filepath, self.sht_name, self.index).read_data()

    def further_process(self):
        self.df['Amount in LC'] = self.df['Debit Amount'] - self.df['Credit Amount']
        agg_func = {"Amount in LC":np.sum}
        grouped_df = self.df.groupby(by = ['Consolidation Account']).agg(agg_func).reset_index()
        return grouped_df
if __name__ == '__main__':

    x = GetTb(r'V:\Accounting\Work\Мерц\2023\3 квартал\Июль 2023\Отчетность\TB_July_2023.xlsx',
        'Sheet1',
          'No')

    x.further_process().to_clipboard()


from custompacks import TxtParser
class GetVendors:
    def __init__(self, filepath, value):
        self.dataframe = TxtParser(filepath,value).read_data()

    def further_process(self):
        df = self.dataframe.copy()
        cols_to_select = ['LIFNR', 'LAND1', 'NAME1', 'NAME2', 'MCOD1', 'MCOD2', 'MCOD3', 'ANRED',
                          'ERDAT', 'ERNAM', 'SPRAS', 'STCD1', 'STCEG', 'STCD3', 'UPDAT',
                          'UPTIM']
        df = df[df['LAND1'].apply(lambda x: len(str(x)) == 2)]
        df = df.loc[:, cols_to_select]
        return df


if __name__ == '__main__':
    parse_data = GetVendors(filepath=r'V:\Findep\Incoming\test\DevOps\References\LFA1 22082023.txt',
                            value='LIFNR').further_process().set_index("LIFNR").T.to_dict()

    print(parse_data.get("101555"))

